===============
Handy Functions
===============

.. image:: https://github.com/ahmedsalhin/hfunctions/workflows/Upload%20Python%20Package/badge.svg
        :target: https://github.com/ahmedsalhin/hfunctions/actions
        :alt: Upload Python Package

.. image:: https://img.shields.io/pypi/v/hfunctions.svg
        :target: https://badge.fury.io/py/hfunctions

.. image:: https://pyup.io/repos/github/ahmedsalhin/hfunctions/shield.svg
        :target: https://pyup.io/repos/github/ahmedsalhin/hfunctions/
        :alt: Updates

.. image:: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue
        :target: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue



Handy tools for ML experimentation
